kubeadm init phase

kubeadm init phase 使您能够调用引导过程的原子步骤。 因此,您可以让 kubeadm 完成一些工作,并且如果您希望应用自定义设置,则可以填写空白。

kubeadm init phase 与 kubeadm init 工作流程 一致,并且在幕后两者都使用相同的代码。

kubeadm init phase preflight

使用此命令,您可以在控制平面节点上执行预检检查。

运行预检检查

概要

运行 kubeadm init 的预检检查。

kubeadm init phase preflight [flags]

示例

  # Run pre-flight checks for kubeadm init using a config file.
  kubeadm init phase preflight --config kubeadm-config.yaml

选项

--config string

kubeadm 配置文件的路径。

--cri-socket string

要连接的 CRI 套接字的路径。如果为空,kubeadm 将尝试自动检测此值;仅当您安装了多个 CRI 或有非标准 CRI 套接字时,才使用此选项。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

preflight 的帮助

--ignore-preflight-errors strings

一个检查列表,其错误将显示为警告。示例:“IsPrivilegedUser,Swap”。值“all”忽略所有检查的错误。

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase kubelet-start

此阶段将写入 kubelet 配置文件和环境变量文件,然后启动 kubelet。

写入 kubelet 设置并(重新)启动 kubelet

概要

写入包含 KubeletConfiguration 的文件和一个包含节点特定 kubelet 设置的环境文件,然后(重新)启动 kubelet。

kubeadm init phase kubelet-start [flags]

示例

  # Writes a dynamic environment file with kubelet flags from a InitConfiguration file.
  kubeadm init phase kubelet-start --config config.yaml

选项

--config string

kubeadm 配置文件的路径。

--cri-socket string

要连接的 CRI 套接字的路径。如果为空,kubeadm 将尝试自动检测此值;仅当您安装了多个 CRI 或有非标准 CRI 套接字时,才使用此选项。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

kubelet-start 的帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--node-name string

指定节点名称。

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase certs

可用于创建 kubeadm 所需的所有证书。

证书生成

概要

证书生成

kubeadm init phase certs [flags]

选项

-h, --help

certs 的帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成所有证书

概要

生成所有证书

kubeadm init phase certs all [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-cert-extra-sans strings

用于 API 服务器服务证书的可选额外主题备用名称 (SAN)。可以是 IP 地址和 DNS 名称。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

all 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

--service-dns-domain string     默认值: "cluster.local"

为服务使用备用域,例如“myorg.internal”。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成自签名 Kubernetes CA,以便为其他 Kubernetes 组件提供身份

概要

生成自签名 Kubernetes CA,以便为其他 Kubernetes 组件提供身份,并将其保存到 ca.crt 和 ca.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs ca [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

ca 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成用于服务 Kubernetes API 的证书

概要

生成用于服务 Kubernetes API 的证书,并将其保存到 apiserver.crt 和 apiserver.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs apiserver [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-cert-extra-sans strings

用于 API 服务器服务证书的可选额外主题备用名称 (SAN)。可以是 IP 地址和 DNS 名称。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

apiserver 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

--service-dns-domain string     默认值: "cluster.local"

为服务使用备用域,例如“myorg.internal”。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 API 服务器连接到 kubelet 的证书

概要

生成 API 服务器连接到 kubelet 的证书,并将其保存到 apiserver-kubelet-client.crt 和 apiserver-kubelet-client.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs apiserver-kubelet-client [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

apiserver-kubelet-client 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成自签名 CA,以便为前端代理提供身份

概要

生成自签名 CA,以便为前端代理提供身份,并将其保存到 front-proxy-ca.crt 和 front-proxy-ca.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs front-proxy-ca [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

front-proxy-ca 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成前端代理客户端的证书

概要

生成前端代理客户端的证书,并将其保存到 front-proxy-client.crt 和 front-proxy-client.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs front-proxy-client [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

front-proxy-client 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成自签名 CA,以便为 etcd 提供身份

概要

生成自签名 CA,以便为 etcd 提供身份,并将其保存到 etcd/ca.crt 和 etcd/ca.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs etcd-ca [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

etcd-ca 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成用于服务 etcd 的证书

概要

生成用于服务 etcd 的证书,并将其保存到 etcd/server.crt 和 etcd/server.key 文件中。

默认 SAN 是 localhost、127.0.0.1、127.0.0.1、::1

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs etcd-server [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

etcd-server 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 etcd 节点彼此通信的证书

概要

生成 etcd 节点彼此通信的证书,并将其保存到 etcd/peer.crt 和 etcd/peer.key 文件中。

默认 SAN 是 localhost、127.0.0.1、127.0.0.1、::1

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs etcd-peer [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

etcd-peer 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成用于活性探测以进行 etcd 健康检查的证书

概要

生成用于活性探测以进行 etcd 健康检查的证书,并将其保存到 etcd/healthcheck-client.crt 和 etcd/healthcheck-client.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs etcd-healthcheck-client [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

etcd-healthcheck-client 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 apiserver 用于访问 etcd 的证书

概要

生成 apiserver 用于访问 etcd 的证书,并将其保存到 apiserver-etcd-client.crt 和 apiserver-etcd-client.key 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs apiserver-etcd-client [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

apiserver-etcd-client 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成用于签署服务帐户令牌的私钥及其公钥

概要

生成用于签署服务帐户令牌的私钥及其公钥,并将其保存到 sa.key 和 sa.pub 文件中。

如果两个文件都已存在,则 kubeadm 将跳过生成步骤,并且将使用现有文件。

kubeadm init phase certs sa [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

sa 的帮助

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase kubeconfig

您可以通过调用 all 子命令来创建所有必需的 kubeconfig 文件,也可以单独调用它们。

生成建立控制平面和管理员 kubeconfig 文件所需的所有 kubeconfig 文件

概要

生成建立控制平面和管理员 kubeconfig 文件所需的所有 kubeconfig 文件

kubeadm init phase kubeconfig [flags]

选项

-h, --help

kubeconfig 的帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成所有 kubeconfig 文件

概要

生成所有 kubeconfig 文件

kubeadm init phase kubeconfig all [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

all 的帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--node-name string

指定节点名称。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为管理员和 kubeadm 本身生成一个 kubeconfig 文件

概要

为管理员和 kubeadm 本身生成 kubeconfig 文件,并将其保存到 admin.conf 文件中。

kubeadm init phase kubeconfig admin [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

管理员帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为 kubelet 生成一个 kubeconfig 文件,仅用于集群引导目的。

概要

为 kubelet 生成 kubeconfig 文件,并将其保存到 kubelet.conf 文件中。

请注意,这仅应用于集群引导目的。在您的控制平面启动后,您应该从 CSR API 请求所有 kubelet 凭据。

kubeadm init phase kubeconfig kubelet [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

kubelet 帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--node-name string

指定节点名称。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为控制器管理器生成 kubeconfig 文件。

概要

为控制器管理器生成 kubeconfig 文件,并将其保存到 controller-manager.conf 文件中。

kubeadm init phase kubeconfig controller-manager [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

控制器管理器帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为调度器生成 kubeconfig 文件。

概要

为调度器生成 kubeconfig 文件,并将其保存到 scheduler.conf 文件中。

kubeadm init phase kubeconfig scheduler [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

调度器帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为超级管理员生成 kubeconfig 文件

概要

为超级管理员生成 kubeconfig 文件,并将其保存到 super-admin.conf 文件中。

kubeadm init phase kubeconfig super-admin [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

超级管理员帮助

--kubeconfig-dir string     默认值: "/etc/kubernetes"

保存 kubeconfig 文件的路径。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase control-plane

使用此阶段,您可以为控制平面组件创建所有必需的静态 Pod 文件。

生成建立控制平面所需的所有静态 Pod 清单文件。

概要

生成建立控制平面所需的所有静态 Pod 清单文件。

kubeadm init phase control-plane [flags]

选项

-h, --help

control-plane 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成所有静态 Pod 清单文件

概要

生成所有静态 Pod 清单文件

kubeadm init phase control-plane all [flags]

示例

  # Generates all static Pod manifest files for control plane components,
  # functionally equivalent to what is generated by kubeadm init.
  kubeadm init phase control-plane all
  
  # Generates all static Pod manifest files using options read from a configuration file.
  kubeadm init phase control-plane all --config config.yaml

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

--feature-gates string

一组描述各种功能的功能门控的键值对。选项为
ControlPlaneKubeletLocalMode=true|false (ALPHA - 默认值=false)
EtcdLearnerMode=true|false (默认值=true)
PublicKeysECDSA=true|false (已弃用 - 默认值=false)
RootlessControlPlane=true|false (ALPHA - 默认值=false)
WaitForAllControlPlaneComponents=true|false (ALPHA - 默认值=false)

-h, --help

all 的帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

--pod-network-cidr string

指定 Pod 网络的 IP 地址范围。如果设置,控制平面将自动为每个节点分配 CIDR。

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 kube-apiserver 静态 Pod 清单。

概要

生成 kube-apiserver 静态 Pod 清单。

kubeadm init phase control-plane apiserver [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

--feature-gates string

一组描述各种功能的功能门控的键值对。选项为
ControlPlaneKubeletLocalMode=true|false (ALPHA - 默认值=false)
EtcdLearnerMode=true|false (默认值=true)
PublicKeysECDSA=true|false (已弃用 - 默认值=false)
RootlessControlPlane=true|false (ALPHA - 默认值=false)
WaitForAllControlPlaneComponents=true|false (ALPHA - 默认值=false)

-h, --help

apiserver 的帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 kube-controller-manager 静态 Pod 清单。

概要

生成 kube-controller-manager 静态 Pod 清单。

kubeadm init phase control-plane controller-manager [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

控制器管理器帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

--pod-network-cidr string

指定 Pod 网络的 IP 地址范围。如果设置,控制平面将自动为每个节点分配 CIDR。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

生成 kube-scheduler 静态 Pod 清单。

概要

生成 kube-scheduler 静态 Pod 清单。

kubeadm init phase control-plane scheduler [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

调度器帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase etcd

使用以下阶段基于静态 Pod 文件创建本地 etcd 实例。

为本地 etcd 生成静态 Pod 清单文件。

概要

为本地 etcd 生成静态 Pod 清单文件。

kubeadm init phase etcd [flags]

选项

-h, --help

etcd 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

为本地、单节点本地 etcd 实例生成静态 Pod 清单文件。

概要

为本地、单节点本地 etcd 实例生成静态 Pod 清单文件。

kubeadm init phase etcd local [flags]

示例

  # Generates the static Pod manifest file for etcd, functionally
  # equivalent to what is generated by kubeadm init.
  kubeadm init phase etcd local
  
  # Generates the static Pod manifest file for etcd using options
  # read from a configuration file.
  kubeadm init phase etcd local --config config.yaml

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

local 帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--patches string

包含名为“target[suffix][+patchtype].extension”的文件的目录的路径。例如,“kube-apiserver0+merge.yaml”或仅“etcd.json”。“target”可以是“kube-apiserver”、“kube-controller-manager”、“kube-scheduler”、“etcd”、“kubeletconfiguration”、“corednsdeployment”之一。“patchtype”可以是“strategic”、“merge”或“json”之一,它们与 kubectl 支持的补丁格式匹配。默认的“patchtype”是“strategic”。“extension”必须是“json”或“yaml”。“suffix”是一个可选字符串,可用于确定首先按字母数字顺序应用哪些补丁。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase upload-config

您可以使用此命令将 kubeadm 配置上传到您的集群。或者,您可以使用 kubeadm config。

将 kubeadm 和 kubelet 配置上传到 ConfigMap

概要

将 kubeadm 和 kubelet 配置上传到 ConfigMap

kubeadm init phase upload-config [flags]

选项

-h, --help

upload-config 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

将所有配置上传到 config map

概要

将所有配置上传到 config map

kubeadm init phase upload-config all [flags]

选项

--config string

kubeadm 配置文件的路径。

--cri-socket string

要连接的 CRI 套接字的路径。如果为空,kubeadm 将尝试自动检测此值;仅当您安装了多个 CRI 或有非标准 CRI 套接字时,才使用此选项。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

all 的帮助

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

将 kubeadm ClusterConfiguration 上传到 ConfigMap

概要

将 kubeadm ClusterConfiguration 上传到 kube-system 命名空间中名为 kubeadm-config 的 ConfigMap。这使得系统组件能够正确配置,并在升级时提供无缝的用户体验。

或者,您可以使用 kubeadm config。

kubeadm init phase upload-config kubeadm [flags]

示例

  # upload the configuration of your cluster
  kubeadm init phase upload-config kubeadm --config=myConfig.yaml

选项

--config string

kubeadm 配置文件的路径。

--cri-socket string

要连接的 CRI 套接字的路径。如果为空,kubeadm 将尝试自动检测此值;仅当您安装了多个 CRI 或有非标准 CRI 套接字时,才使用此选项。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

kubeadm 帮助

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

将 kubelet 组件配置上传到 ConfigMap

概要

将从 kubeadm InitConfiguration 对象中提取的 kubelet 配置上传到集群中的 kubelet-config ConfigMap

kubeadm init phase upload-config kubelet [flags]

示例

  # Upload the kubelet configuration from the kubeadm Config file to a ConfigMap in the cluster.
  kubeadm init phase upload-config kubelet --config kubeadm.yaml

选项

--config string

kubeadm 配置文件的路径。

--cri-socket string

要连接的 CRI 套接字的路径。如果为空,kubeadm 将尝试自动检测此值;仅当您安装了多个 CRI 或有非标准 CRI 套接字时,才使用此选项。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

kubelet 帮助

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase upload-certs

使用以下阶段将控制平面证书上传到集群。默认情况下,证书和加密密钥在两小时后过期。

将证书上传到 kubeadm-certs

概要

将控制平面证书上传到 kubeadm-certs Secret

kubeadm init phase upload-certs [flags]

选项

--certificate-key string

用于加密 kubeadm-certs Secret 中控制平面证书的密钥。证书密钥是一个十六进制编码的字符串,它是大小为 32 字节的 AES 密钥。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

upload-certs 帮助

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

--skip-certificate-key-print

不打印用于加密控制平面证书的密钥。

--upload-certs

将控制平面证书上传到 kubeadm-certs Secret。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase mark-control-plane

使用以下阶段将节点标记并污点为控制平面节点。

将节点标记为控制平面

概要

将节点标记为控制平面

kubeadm init phase mark-control-plane [flags]

示例

  # Applies control-plane label and taint to the current node, functionally equivalent to what executed by kubeadm init.
  kubeadm init phase mark-control-plane --config config.yaml
  
  # Applies control-plane label and taint to a specific node
  kubeadm init phase mark-control-plane --node-name myNode

选项

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

mark-control-plane 帮助

--node-name string

指定节点名称。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase bootstrap-token

使用以下阶段配置引导令牌。

生成用于将节点加入集群的引导令牌

概要

引导令牌用于在加入集群的节点和控制平面节点之间建立双向信任。

此命令进行使引导令牌工作所需的所有配置,然后创建一个初始令牌。

kubeadm init phase bootstrap-token [flags]

示例

  # Make all the bootstrap token configurations and create an initial token, functionally
  # equivalent to what generated by kubeadm init.
  kubeadm init phase bootstrap-token

选项

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

bootstrap-token 帮助

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

--skip-token-print

跳过打印“kubeadm init”生成的默认引导令牌。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase kubelet-finalize

使用以下阶段在 TLS 引导后更新与 kubelet 相关的设置。您可以使用 all 子命令运行所有 kubelet-finalize 阶段。

在 TLS 引导后更新与 kubelet 相关的设置

概要

在 TLS 引导后更新与 kubelet 相关的设置

kubeadm init phase kubelet-finalize [flags]

示例

  # Updates settings relevant to the kubelet after TLS bootstrap"
  kubeadm init phase kubelet-finalize all --config

选项

-h, --help

kubelet-finalize 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

运行所有 kubelet-finalize 阶段

概要

运行所有 kubelet-finalize 阶段

kubeadm init phase kubelet-finalize all [flags]

示例

  # Updates settings relevant to the kubelet after TLS bootstrap"
  kubeadm init phase kubelet-finalize all --config

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

all 的帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

启用 kubelet 客户端证书轮换 (已弃用:请改用 'enable-client-cert-rotation')

概要

启用 kubelet 客户端证书轮换 (已弃用:请改用 'enable-client-cert-rotation')

kubeadm init phase kubelet-finalize experimental-cert-rotation [flags]

选项

--cert-dir string     默认值: "/etc/kubernetes/pki"

保存和存储证书的路径。

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

experimental-cert-rotation 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

kubeadm init phase addon

您可以使用 all 子命令安装所有可用的插件,或选择性地安装它们。

安装通过一致性测试所需的插件

概要

安装通过一致性测试所需的插件

kubeadm init phase addon [flags]

选项

-h, --help

addon 帮助

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

安装所有插件

概要

安装所有插件

kubeadm init phase addon all [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

--feature-gates string

一组描述各种功能的功能门控的键值对。选项为
ControlPlaneKubeletLocalMode=true|false (ALPHA - 默认值=false)
EtcdLearnerMode=true|false (默认值=true)
PublicKeysECDSA=true|false (已弃用 - 默认值=false)
RootlessControlPlane=true|false (ALPHA - 默认值=false)
WaitForAllControlPlaneComponents=true|false (ALPHA - 默认值=false)

-h, --help

all 的帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--pod-network-cidr string

指定 Pod 网络的 IP 地址范围。如果设置,控制平面将自动为每个节点分配 CIDR。

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

--service-dns-domain string     默认值: "cluster.local"

为服务使用备用域,例如“myorg.internal”。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

将 CoreDNS 插件安装到 Kubernetes 集群。

概要

通过 API 服务器安装 CoreDNS 插件组件。请注意,虽然部署了 DNS 服务器,但在安装 CNI 之前它不会被调度。

kubeadm init phase addon coredns [flags]

选项

--config string

kubeadm 配置文件的路径。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

--feature-gates string

一组描述各种功能的功能门控的键值对。选项为
ControlPlaneKubeletLocalMode=true|false (ALPHA - 默认值=false)
EtcdLearnerMode=true|false (默认值=true)
PublicKeysECDSA=true|false (已弃用 - 默认值=false)
RootlessControlPlane=true|false (ALPHA - 默认值=false)
WaitForAllControlPlaneComponents=true|false (ALPHA - 默认值=false)

-h, --help

coredns 帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--print-manifest

将插件清单打印到 STDOUT 而不是安装它们

--service-cidr string     默认值: "10.96.0.0/12"

为服务 VIP 使用备用 IP 地址范围。

--service-dns-domain string     默认值: "cluster.local"

为服务使用备用域,例如“myorg.internal”。

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

将 kube-proxy 插件安装到 Kubernetes 集群。

概要

通过 API 服务器安装 kube-proxy 插件组件。

kubeadm init phase addon kube-proxy [flags]

选项

--apiserver-advertise-address string

API 服务器将公布其正在侦听的 IP 地址。如果未设置,将使用默认网络接口。

--apiserver-bind-port int32     默认值: 6443

API 服务器要绑定到的端口。

--config string

kubeadm 配置文件的路径。

--control-plane-endpoint string

为控制平面指定稳定的 IP 地址或 DNS 名称。

--dry-run

不要应用任何更改;仅输出将要执行的操作。

-h, --help

kube-proxy 帮助

--image-repository string     默认值: "registry.k8s.io"

选择要从中拉取控制平面镜像的容器注册表

--kubeconfig string     默认值: "/etc/kubernetes/admin.conf"

与集群通信时使用的 kubeconfig 文件。如果未设置此标志,则可以搜索一组标准位置以查找现有的 kubeconfig 文件。

--kubernetes-version string     默认值: "stable-1"

为控制平面选择特定的 Kubernetes 版本。

--pod-network-cidr string

指定 Pod 网络的 IP 地址范围。如果设置,控制平面将自动为每个节点分配 CIDR。

--print-manifest

将插件清单打印到 STDOUT 而不是安装它们

从父命令继承的选项

--rootfs string

“真实”主机根文件系统的路径。这将导致 kubeadm chroot 到提供的路径中。

有关 v1beta4 配置中每个字段的更多详细信息,您可以导航到我们的 API 参考页面。

下一步

上次修改时间:2024年8月17日下午4:50 PST: 更新对生成页面的引用 (3b6f229424)